==> p5-GRNOC-TL1-1.2.2.tbz: lib/perl5/site_perl/5.14.2/GRNOC/TL1/Device/Cisco/ONS15808.pm <==
#--------------------------------------------------------------------
#----- GRNOC TL1 Cisco ONS15808 Device Module
#-----
#----- Copyright(C) 2008 The Trustees of Indiana University
#--------------------------------------------------------------------
#----- $HeadURL: $
#----- $Id: $
#-----
#----- This module handles the functionality for the Cisco ONS 15808 TL1 device.  It
#----- inherts from the standard GRNOC::TL1::Device module.
#--------------------------------------------------------------------

package GRNOC::TL1::Device::Cisco::ONS15808;
use base "GRNOC::TL1::Device";

use Data::Dumper;
use strict;

sub new {

  my $caller = shift;
  my $class = ref($caller) || $caller;
  
  my (%args) = @_;

  # set default port used for ONS 15808 if one was not given
  $args{'port'} = 1000 if ($args{'port'} eq '');

  # set default prompt used for ONS 15808 if one was not given
  $args{'prompt'} = ';' if ($args{'prompt'} eq '');

  # we almost certainly don't want to wait for a login prompt
  $args{'wait_for_login_prompt'} = 0 if ($args{'wait_for_login_prompt'} eq '');

  # call the GRNOC::TL1::Device structure
  my $self = $class->SUPER::new(%args);

  bless($self, $class);
  
  return $self;
}

sub login {

  my $self = shift;

  # be a little nicer and wait a few secs before trying to login
  sleep(2);

  # also, do like the 808 documentation example and send an empty ; first
  $self->cmd(";");

  # now login
  return $self->SUPER::login();
}

sub get_alarms {

  my $self = shift;
  
  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};

  my $cmd = "RTRV-ALM:$tid:ALL:$ctag;";

  my @output_messages = $self->parse($self->cmd($cmd));
  my @responses = $self->get_responses(@output_messages);
  my @alarms;

  foreach my $response (@responses) {

    my $alarm;

    if ($response =~ /"([^:]*):([^,]*),([^,]*),([^,]*),([^,]*),([^,]*),,:([^,]*),"/) {
      
      $alarm->{'aid'} = $1;
      $alarm->{'not_code'} = $2;
      $alarm->{'cond_type'} = $3;
      $alarm->{'serv_affect'} = $4;
      $alarm->{'date'} = $5;
      $alarm->{'time'} = $6;
      $alarm->{'description'} = $7;

      $alarm->{'description'} =~ s/\\//g;
      $alarm->{'description'} =~ s/"//g;
      
      $alarm->{'time'} =~ s/-/:/g;
      
      push(@alarms, $alarm);
    }

    else {

      print STDERR "get_alarms: Error parsing alarm string: $response\n";
    }
  }
  
  return @alarms;
}

sub get_inventory {

  my $self = shift;
  
  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};

  my $cmd = "RTRV-EQPT:$tid:ALL:$ctag;";

  my @output_messages = $self->parse($self->cmd($cmd));
  my @responses = $self->get_responses(@output_messages);
  my @inventory;

  foreach my $response (@responses) {

    my $device;

    if ($response =~ /^"([^:]+):([^"]+)"$/) {

      $device->{'aid'} = $1;
      $device->{'state'} = $2;
      
      push(@inventory, $device);
    }
    
    else {
      
      print STDERR "get_inventory: Error parsing response: $response\n";
    }
  }

  return @inventory;
}

sub get_performance_data {

  my ($self, $aid) = @_;

  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};
  
  my $cmd = "RTRV-PM:$tid:$aid:$ctag;";

  my @output_messages = $self->parse($self->cmd($cmd));
  my @responses = $self->get_responses(@output_messages);
  my @datum;

  foreach my $response (@responses) {

    my $data;

    my ($data_aid, $type, $value) = $response =~ /^"([^:]+):([^,]+),([^,]+),/;
    
    $data->{'type'} = $type;
    $data->{'value'} = $value;

    push(@datum, $data);
  }

  return @datum;
}

1;

==> p5-GRNOC-TL1-1.3.10.tbz: lib/perl5/site_perl/5.14/GRNOC/TL1/Device/Cisco/ONS15808.pm <==
#--------------------------------------------------------------------
#----- GRNOC TL1 Cisco ONS15808 Device Module
#-----
#----- Copyright(C) 2008 The Trustees of Indiana University
#--------------------------------------------------------------------
#----- $HeadURL: $
#----- $Id: $
#-----
#----- This module handles the functionality for the Cisco ONS 15808 TL1 device.  It
#----- inherts from the standard GRNOC::TL1::Device module.
#--------------------------------------------------------------------

package GRNOC::TL1::Device::Cisco::ONS15808;
use base "GRNOC::TL1::Device";

use Data::Dumper;
use strict;

sub new {

  my $caller = shift;
  my $class = ref($caller) || $caller;
  
  my (%args) = @_;

  # set default port used for ONS 15808 if one was not given
  $args{'port'} = 1000 if ($args{'port'} eq '');

  # set default prompt used for ONS 15808 if one was not given
  $args{'prompt'} = ';' if ($args{'prompt'} eq '');

  # we almost certainly don't want to wait for a login prompt
  $args{'wait_for_login_prompt'} = 0 if ($args{'wait_for_login_prompt'} eq '');

  # call the GRNOC::TL1::Device structure
  my $self = $class->SUPER::new(%args);

  bless($self, $class);
  
  return $self;
}

sub login {

  my $self = shift;

  # be a little nicer and wait a few secs before trying to login
  sleep(2);

  # also, do like the 808 documentation example and send an empty ; first
  my $cmd_output = $self->cmd(";");

  return undef if (!defined $cmd_output);

  # now login
  return $self->SUPER::login();
}

sub get_alarms {

  my $self = shift;
  
  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};

  my $cmd = "RTRV-ALM:$tid:ALL:$ctag;";

  my $cmd_output = $self->cmd($cmd);
  return undef if (!defined $cmd_output);

  my @output_messages = $self->parse($cmd_output);
  my @responses = $self->get_responses(@output_messages);
  my @alarms;

  foreach my $response (@responses) {

    my $alarm;

    if ($response =~ /"([^:]*):([^,]*),([^,]*),([^,]*),([^,]*),([^,]*),,:([^,]*),"/) {
      
      $alarm->{'aid'} = $1;
      $alarm->{'not_code'} = $2;
      $alarm->{'cond_type'} = $3;
      $alarm->{'serv_affect'} = $4;
      $alarm->{'date'} = $5;
      $alarm->{'time'} = $6;
      $alarm->{'description'} = $7;

      $alarm->{'description'} =~ s/\\//g;
      $alarm->{'description'} =~ s/"//g;
      
      $alarm->{'time'} =~ s/-/:/g;
      
      push(@alarms, $alarm);
    }

    else {

      print STDERR "get_alarms: Error parsing alarm string: $response\n";
    }
  }
  
  return @alarms;
}

sub get_inventory {

  my $self = shift;
  
  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};

  my $cmd = "RTRV-EQPT:$tid:ALL:$ctag;";

  my $cmd_output = $self->cmd($cmd);
  return undef if (!defined $cmd_output);

  my @output_messages = $self->parse($cmd_output);
  my @responses = $self->get_responses(@output_messages);
  my @inventory;

  foreach my $response (@responses) {

    my $device;

    if ($response =~ /^"([^:]+):([^"]+)"$/) {

      $device->{'aid'} = $1;
      $device->{'state'} = $2;
      
      push(@inventory, $device);
    }
    
    else {
      
      print STDERR "get_inventory: Error parsing response: $response\n";
    }
  }

  return @inventory;
}

sub get_performance_data {

  my ($self, $aid) = @_;

  my $ctag = $self->{'ctag'};
  my $tid = $self->{'tid'};
  
  my $cmd = "RTRV-PM:$tid:$aid:$ctag;";

  my $cmd_output = $self->cmd($cmd);
  return undef if (!defined $cmd_output);

  my @output_messages = $self->parse($cmd_output);
  my @responses = $self->get_responses(@output_messages);
  my @datum;

  foreach my $response (@responses) {

    my $data;

    my ($data_aid, $type, $value) = $response =~ /^"([^:]+):([^,]+),([^,]+),/;
    
    $data->{'type'} = $type;
    $data->{'value'} = $value;

    push(@datum, $data);
  }

  return @datum;
}

1;
